#!/usr/bin/env python
# $Id$
''' Simple Terminal Application using python vte module '''
import os
from stat import S_IEXEC, ST_MODE
import gtk, vte
import pygtk
pygtk.require('2.0')

class MyTerminal:
    ''' Simple terminal class using vte '''
    def __init__(self, shell = None):
        ''' Intialize class with gtk window and default shell '''
        self.__shell = shell
        
        self.__window = gtk.Window(gtk.WINDOW_TOPLEVEL)
        self.__window.set_title("Python Terminal")
        self.__window.set_border_width(0)
        self.__window.connect("delete_event", lambda w, e: gtk.main_quit())
        
        self.__terminal = vte.Terminal()
        self.__terminal.connect("child_exited", lambda w: gtk.main_quit())
        
        self.__window.add(self.__terminal)

    def __shell_is_executable(self):
        ''' Check to see if shell is executable '''
        if self.__shell:
            mode = os.stat(self.__shell)[ST_MODE]
            # See if executable using bitwise AND
            if mode & S_IEXEC:
                return True
        return False

    def set_shell(self, shell = None):
        ''' Set terminal shell '''
        self.__shell = shell
        if os.path.isfile(os.path.realpath(self.__shell)):
            if self.__shell_is_executable():
                return True
        else:
            print self.__shell + " is not a valid shell"
            print "Trying $SHELL environment variable"
        try:
            self.__shell = os.environ['SHELL']
            if self.__shell_is_executable():
                return True
        except KeyError:
            print "Unable to get shell from $SHELL. Trying /bin/sh"
        self.__shell = '/bin/sh'
        if self.__shell_is_executable():
            return True
        return False

    def get_shell(self):
        ''' get default shell for user terminal '''
        return self.__shell

    def run(self):        
        ''' Execute shell in gtk window '''
        if not self.set_shell(self.__shell):
            print "Unable to find an appropriate shell"
            return False
        self.__terminal.show()
        self.__window.show()
        self.__terminal.fork_command(self.__shell)
        
        gtk.main()
        return True

if __name__ == "__main__":
    MYTERM = MyTerminal()
    MYTERM.set_shell('/bin/bash1')
    MYTERM.run()

# vim:syntax=python
# vim:sw=4:softtabstop=4:expandtab
